KtClassKind

Enum KtClassKind 

pub enum KtClassKind {
    Plain,
    Abstract,
    Data,
    Enum(Vec<KtEnumEntry>),
    ValueInline,
    Object,
    Companion,
    Interface,
    SealedInterface,
    DataObject,
}
The kind of class-like declaration.

Variants



Plain



Abstract



Data



Enum(Vec<KtEnumEntry>)

Enum class with its entries.



ValueInline

@JvmInline value class (the annotation is added by the renderer).



Object



Companion

companion object (only valid as KtClass::companion).



Interface

A plain interface — members with no body render as abstract signatures; no ctor params.



SealedInterface

A sealed interface — an exhaustive set of alternatives whose implementations are nested inside it as Self::Data classes and Self::DataObjects.



DataObject

A data object — the singleton counterpart of a data class, for an alternative that carries no payload.